# DPIVSoft python

DPIVSoft is an open PIV algorithm developed by Thomas Leweke and Patrice Munier. The original source of DPIVSoft for Matlab enviorement is accesible at the following link: <https://www.irphe.fr/~meunier/>. This project tries to migrate the original source to a python enviorement and also add the capabilites of GPU computing using OpenCL.

DPIVSoft consist in Python and OpenCL modules for scripting and executing the analysis of 2D PIV image pairs. At current state some Python knowledge is needed to use this software. A graphic user interface is planned to be added to make the software more accesible to people without programming skills.

## Warning

The DPIVSoft Python version is still in it's *beta* state. This means that it can have some bugs and the API may change. However, testing and contributing is very welcome.

## Installing
Note: DPIVSoft is only compatible with Python 3.7 & 3.8

### To build from source
Be sure you already have installed the package setuptools, otherwise install it using:

```bash
$ pip install setuptools
```

Download the package from the gitlab link: <https://gitlab.com/jacabello/dpivsoft_python/-/archive/master/dpivsoft_python-master.zip>

or clone using git

```bash
$ git clone https://gitlab.com/jacabello/dpivsoft_python.git
```

For the global installation, first step is go to the source folder and generate an installable using the following command:

```bash
$ python setup.py sdist
```

If everithing is fine, a folder named "dist" must have been created. Install the installable generated inside "dist" folder by using:

```bash
$ pip install Installable_Name
```

### Install directly using pip (not ready yet)
Alternatively DPIVSoft can be installed using PyPI: <https://the_pip_domain>:

```bash
$ pip install dpivsoft
```

## Learning to use DPIVSoft
In the distribution there are included tutorials and examples of how to compute PIV on source_folder/Examples

# Developing DPIVSOFT
To install dpivsoft, along with the tools that you need to develop and run test, run the following line in your virtualenv:

```bash
$ pip install -e.[dev]
```

## Contributors

1. [Jorge Aguilar-Cabello](https://gitlab.com/jacabello)

## Akcnowledgment

1. Patrice Meunier
2. Thomas Leweke
3. [Raul Infantes-Sainz](https://gitlab.com/infantesainz)
4. [Luis Parras](https://gitlab.com/lparras)
5. Carlos del Pino

## How to cite this work


